@@ -55,6 +55,44 @@ class VaultClient():
 
         return self._client.secrets.kv.v2.read_secret_version(
             mount_point=mount_point, path=path)['data']['data'][secret]
+    
+    def encrypt_secret(self, transit_path: str, key_name: str,  plaintext: str) -> str:
+        """Encrypts a secret and returns the ciphertext
+        
+        Parameters
+        ----------        
+        transit_path: str, {system}/transit (usually)
+        key_name: str, name of the backend key
+        plaintext: str, base64
+        
+        Returns
+        -------
+        str, format: vault:v1:{ciphertext}, where the entire string should be sent to vault for decryption
+        """
+        if not self._client.is_authenticated():
+            self._authenticate_func(self._client)
+        
+        response = self._client.secrets.transit.encrypt_data(key_name, plaintext, mount_point=transit_path)
+        return response['data']['ciphertext']
+
+    def decrypt_secret(self, transit_path: str, key_name: str, ciphertext: str) -> str:
+        """Encrypts a secret and returns the ciphertext
+        
+        Parameters
+        ----------        
+        transit_path: str, {system}/transit (usually)
+        key_name: str, name of the backend key
+        ciphertext: str, format: vault:v1:{ciphertext}
+        
+        Returns
+        -------
+        str, base64
+        """
+        if not self._client.is_authenticated():
+            self._authenticate_func(self._client)
+            
+        response = self._client.secrets.transit.decrypt_data(key_name, ciphertext, mount_point=transit_path)
+        return response['data']['plaintext']
 
     @staticmethod
     def is_in_cluster() -> bool:
@@ -70,9 +108,14 @@ class VaultClient():
 
         decoded_token = jwt.decode(jwt_token,
                                    options={"verify_signature": False})
-        namespace = decoded_token["kubernetes.io/serviceaccount/namespace"]
-        serviceaccount_name = decoded_token[
-            "kubernetes.io/serviceaccount/service-account.name"]
+
+        if "kubernetes.io/serviceaccount/namespace" in decoded_token:
+            namespace = decoded_token["kubernetes.io/serviceaccount/namespace"]
+            serviceaccount_name = decoded_token[
+                "kubernetes.io/serviceaccount/service-account.name"]
+        else:
+            namespace = decoded_token['kubernetes.io']['namespace']
+            serviceaccount_name = decoded_token["kubernetes.io"]["serviceaccount"]["name"]
 
         vault_client = hvac.Client(url=vault_addr)
         mount_point = f"{vault_base_mount_point}{namespace}/{serviceaccount_name}"
